#include <avr\io.h>
#include <avr\interrupt.h>

//-------------------- P O R T S ---------------------

#define PortsInit()			(DDRB  |=  0x04, DDRD |= 0x80)
#define DebugWireOn()		(PORTD |=  0x80)
#define DebugWireOff()		(PORTD &=~ 0x80)
#define DebugWireToggle()	(PORTD ^=  0x80)

//--------------------- P W M ------------------------
#define PwmInit()				(TCCR1A |= 0x23, TCCR1B |= 0x18, TIMSK1 |=2)
#define PwmSetTop(a)			(OCR1A = a)		
#define PwmSet(a)				(OCR1B = a)
#define PwmStart(a)			(TCCR1B |= a)
#define PwmStop()				(TCCR1B &=~ 7)

//-------------- A D  C O N V E R T E R --------------
#define AdcInit()				(ADCSRA |= 0x88)
#define AdcPrescaler(a)    (ADCSRA &=~ a, ADCSRA |= a)
#define AdcMuxSelect(a)		(ADMUX &=~ 15, ADMUX  |= a)
#define AdcStart()			(ADCSRA |= 0x40)
#define SHUNT					0
#define USER					1

static unsigned int adc_test[256];
static unsigned char adc_pointer;

//Compare match PWM interrupt vector (TOP value)
ISR(TIMER1_COMPA_vect){
	
	AdcStart();

	DebugWireToggle();	
}

//ADC conversion compete interrupt vector
ISR(ADC_vect){

	adc_test[adc_pointer++] = ADC;

	DebugWireToggle();
}


int main(void){
	unsigned char pero;
	//Init PWM timer
	PwmInit();
	
	//Set Top value for PWM timer
	PwmSetTop(0x3FF);
	
	//Set PWM 
	PwmSet(0x70);

	//Start PWM Timer (No prescaling)
	PwmStart(1);

	//Init Data Direction
	PortsInit();
	
	//Init ADC
	AdcInit();
	
	//Select ADC prescaler
	AdcPrescaler(5);
	
	//Select AD Mux (Input port)
	AdcMuxSelect(SHUNT);
	
	//Enable global interrupts	
	sei();

	//loop forever
	while(1){

		//Do nothing
	}	
}
